@@ -15,7 +15,7 @@
 #
 
 
-from .base import RestEndpointBuilder
+from splunk_add_on_ucc_framework.uccrestbuilder.endpoint.base import RestEndpointBuilder
 
 """
 This class is used to generate the endpoint for getting access token from
